"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const camelCase = require('lodash/camelCase');
class Init {
    constructor(name, options = {}) {
        this.name = name;
        this.additionalPromptsEntries = options.prompts || [];
        this.default = options.default;
        this.files = options.files || [];
        this.before = options.before ? options.before.bind(this) : options.before;
        this.after = options.after ? options.after.bind(this) : options.after;
        this.init = options.init ? options.init.bind(this) : options.init;
    }
    prompts() {
        const prompts = [];
        const mainPrompt = this.mainPrompts();
        if (mainPrompt) {
            prompts.push(...mainPrompt);
        }
        const additionalPrompts = this.additionalPrompts();
        if (additionalPrompts) {
            prompts.push(...additionalPrompts);
        }
        return prompts;
    }
    mainPrompts() {
        return [
            {
                type: 'confirm',
                name: this.initVariable,
                message: `Initialize ${this.name}`,
                default: this.default,
                store: true
            }
        ];
    }
    additionalPrompts(init) {
        if (!init) {
            init = this;
        }
        return init.additionalPromptsEntries.map(prompt => {
            return Object.assign({}, prompt, {
                when: (answers) => {
                    return answers[this.initVariable];
                }
            });
        });
    }
    get initVariable() {
        return `${camelCase(this.name)}Init`;
    }
}
const inits = [
    new Init('drupal', {
        default: false,
        prompts: [
            {
                type: 'list',
                name: 'drupalInitProfil',
                message: 'Profil',
                store: true,
                default: 'standard',
                choices: ['standard', 'gfi']
            }
        ],
        files: ['.bin/drush', '.bin/drupal'],
        before(generator) {
            if (generator.answers.get('nodeSassContainer')) {
                this.files.push('.bin/build-sass');
                this.files.push('.bin/watch-sass');
            }
        }
    })
];
exports.default = inits;
//# sourceMappingURL=inits.js.map