"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const extend = require('deep-extend');
const path = require('path');
const Handlebars = require("handlebars");
Handlebars.registerHelper('if_eq', function (a, b, opts) {
    if (a === b)
        return opts.fn(this);
    return opts.inverse(this);
});
function copyTpl(generator, from, to, tplSettings, options) {
    const context = generator.answers || {};
    options = extend(options || {}, { globOptions: { dot: true } });
    try {
        generator.fs.copy(from, to, extend(options, {
            process: function (contents, filename) {
                if (filename.endsWith('.hbs')) {
                    const precompileTplSettings = extend({ srcName: filename }, tplSettings);
                    const templateAst = Handlebars.parse(contents.toString(), precompileTplSettings);
                    const template = Handlebars.compile(templateAst);
                    return template(context);
                }
                return contents;
            }
        }));
    }
    catch (err) {
        if (!(err instanceof assert_1.AssertionError)) {
            throw err;
        }
        // No files maches from glob
    }
}
exports.copyTpl = copyTpl;
function copyAllTpl(generator, includes) {
    for (const defaultInclude of includes) {
        let destination;
        if (defaultInclude.indexOf('*') > -1) {
            destination = generator.destinationRoot();
        }
        else {
            destination = path.join(generator.destinationRoot(), defaultInclude);
        }
        copyTpl(generator, generator.templatePath(`${defaultInclude}`), destination);
    }
}
exports.copyAllTpl = copyAllTpl;
//# sourceMappingURL=templating.js.map